import sys

from chemscripts.calc import queue
from chemscripts.mylogging import createLogger
from chemscripts import utils, geom

STARTFILE = "./meoome.log" # The name of optimization log-file

if __name__ == "__main__":
    for exe in ("rung",):
        assert utils.check_availability(exe), "%s is not included in PATH" % exe

    if len(sys.argv) > 1:
        maxproc = int(sys.argv[1])
    else:
        maxproc = None
    gdriver = queue.init_thread(maxproc)
    logger = createLogger("Main")

    logger.info("Step 1. Run NBO3 analysis for initial geometry")
    logger.info("Processing " + STARTFILE)
    xyzs, syms = utils.parse_gaussian_log(STARTFILE)
    gjfname = STARTFILE.replace('.log', '_nbo3.gjf')
    utils.write_gjf(xyzs, syms, 'nbosimple', gjfname,
                    subs={
                        'nproc': 1,
                    })
    nbogjfs = [gjfname]
    utils.start_calcs(nbogjfs, gdriver)
    logger.info("Step 1 is finished")

    logname = gjfname.replace('.gjf', '.log')
    logger.info("Step 2. Generate SDFs with topologies from NBO for Blender")
    logger.info("Reading " + logname)

    curmol = geom.Molecule(nbolog=logname)
    curmol.from_xyz(xyzs, syms)
    sdfname = STARTFILE.replace('.log', '.sdf')
    curmol.save_sdf(sdfname)
    logger.info("Step 2 is finished")

    logger.info("My work is done. Terminating.")
    with gdriver['todo_lock']:
        gdriver['todo_files'].append("Done")
