# ./orbitals/draw_orbitals.py

import bpy
import sys, os, json, ntpath
mycwd = os.getcwd()
if mycwd not in sys.path:
    sys.path.insert(0, mycwd)
import chemscripts.blender as msblend
import chemscripts.blender.draw_objects.orbitals as msorbital
msblend.cleanup()

SDFNAME = "./calc_files/meoome.sdf" # The file generated earlier
SMALL_ATOMS = [] # Atoms that have to be smaller than others, indices start from 1
RESFILE = "meoome_scene.blend" # Filename for the generated scene
ASSIGNMENT_FNAME = "./nbo_assignment.json" # or "./mo_assignment.json"
CALCDIR = "./calc_files" # Dir for all new files
PLOT_ORBITALS = ["donor", "acceptor"] # Names of NBOs
# PLOT_ORBITALS = ["HOMO", "LUMO"] # or names of MOs

with open(ASSIGNMENT_FNAME, 'r') as f:
    orbital_data = json.load(f)
molname = ntpath.basename(SDFNAME).replace('.sdf', '')

m = msblend.Molecule(small_atoms=SMALL_ATOMS)
m.read_sdf(SDFNAME)
m.draw_bonds(caps=False, radius=0.1)
m.draw_atoms(scale=0.35)

for orbname in PLOT_ORBITALS:
    orbidx = orbital_data[molname][orbname]
    if "HOMO" in orbname or "LUMO" in orbname:
        filenames = f"{molname}_scf_{orbidx}" # For MOs
    else:
        filenames = f"{molname}_nbo3_{orbidx}" # For NBOs
    
    # 1) Different colors for different signs
    # msorbital.plot_nbo(filenames, nbodir=CALCDIR, color=["#DF4A4A", "#64A7E7"], reverse=False)
    # 2) Monochromatic style
    msorbital.plot_nbo(filenames, nbodir=CALCDIR, color="#f363e0", reverse=False)
    # 3) To get zebra-like orbitals: color=["#111111", "#FFFFFF"], wavy=True

bpy.ops.wm.save_as_mainfile(filepath=os.path.join(os.getcwd(), RESFILE))
