# ./postprocessing/image2image.py

import glob
from PIL import Image, ImageEnhance
from chemscripts import imageutils

IMAGE_MASK = "./*_rendered.png" # Files to process
TO_FINAL = lambda old_name: old_name.replace("_rendered.png", "_final.png") # Rule for renaming
BRIGHTNESS = 1.3

if __name__ == '__main__':
    for pngname in glob.glob(IMAGE_MASK):
        main_image = Image.open(pngname)
        main_image.load()
        # Fills the transparency
        bg = Image.new("RGB", main_image.size, (255, 255, 255))
        bg.paste(main_image, mask=main_image.split()[3])
        main_image = bg

        # Increases brightness
        enhancer = ImageEnhance.Brightness(main_image)
        main_image = enhancer.enhance(BRIGHTNESS)

        # Trims white space
        trimbox = imageutils.TrimmingBox()
        trimbox.extend(main_image)
        main_image = main_image.crop(trimbox.points)

        newpngname = TO_FINAL(pngname)
        main_image.save(newpngname, 'PNG', quality=100)
